pub fn server_tls(certs: &TestCerts) -> ServerTlsExpand description
A [ServerTls] presenting certs.
Panics
Panics if certs does not parse, which does not happen for a pair
from self_signed.
pub fn server_tls(certs: &TestCerts) -> ServerTlsA [ServerTls] presenting certs.
Panics if certs does not parse, which does not happen for a pair
from self_signed.